// ADS Point lighting Shader
#version 130
in vec4 vVertex;
in vec3 vNormal;
in vec2 vTexture0;

uniform mat4 mvpMatrix;
uniform mat4 mvMatrix;
uniform mat3 normalMatrix;
uniform vec3 vLightPosition;
uniform mat4 lightMatrix;

// Color to fragment program
out vec3 vVaryingNormal;
out vec3 vVaryingLightDir;
out vec2 vTexCoords;

out vec4 projCoord;

void main(void) 
{ 
	// Get surface normal in eye coordinates
	vVaryingNormal = normalMatrix * vNormal;

	// Get vertex position in eye coordinates
	vec4 vPosition4 = mvMatrix * vVertex;
	vec3 vPosition3 = vPosition4.xyz / vPosition4.w;

	// Get vector to light source
	vVaryingLightDir = normalize(vLightPosition - vPosition3);

	// Pass along the texture coordinates
	vTexCoords = vTexture0;

	projCoord = lightMatrix * vVertex;

	// Don't forget to transform the geometry!
	gl_Position = mvpMatrix * vVertex;
}
